@@ -290,7 +290,7 @@ impl<'data> SymbolMap<'data> {
         }
     }
 
-    /// Looks up a symbol in the symbol map.
+    /// Looks up the symbol covering the given address.
     pub fn lookup(&self, address: u64) -> Option<&Symbol<'data>> {
         match self.symbols.binary_search_by_key(&address, Self::key) {
             Ok(index) => Some(&self.symbols[index]),
@@ -306,6 +306,15 @@ impl<'data> SymbolMap<'data> {
         }
     }
 
+    /// Looks up a symbol by its start address.
+    pub fn lookup_exact(&self, address: u64) -> Option<&Symbol<'data>> {
+        let idx = self
+            .symbols
+            .binary_search_by_key(&address, Self::key)
+            .ok()?;
+        self.symbols.get(idx)
+    }
+
     /// Looks up a symbol covering an entire range.
     ///
     /// This is similar to [`lookup`], but it only returns the symbol result if it _also_ covers the
@@ -430,6 +439,7 @@ pub struct FileInfo<'data> {
 
 impl<'data> FileInfo<'data> {
     /// Creates a `FileInfo` from a joined path by trying to split it.
+    #[cfg(any(feature = "breakpad", feature = "ms", feature = "sourcebundle"))]
     pub(crate) fn from_path(path: &'data [u8]) -> Self {
         let (dir, name) = symbolic_common::split_path_bytes(path);
 
